
<!---
FrozenIsBool True
-->

##Example

We can do also an encapsulating pointing when the SetKeyVariable is has an equivalent key str with a PrefixPathStr in the end. In that case, the encapsulating pointer is attributed with a PointFromVariable and PointToVariable.